import { Path } from '@angular-devkit/core';
import { Rule } from '@angular-devkit/schematics';
import { SchemaExplorer } from '@lightweightform/theme-common/schematics';
import { FormOptions } from './form.options';
/**
 * `form` schematic function.
 * @param options Schematic options.
 * @returns Schematic rule.
 */
export declare function form(options: FormOptions): Rule;
/**
 * Creates the form collection.
 * @param options Schematic options.
 * @param schemaExplorer `SchemaExplorer` instance.
 * @param moduleDir Module directory where to find the root schema.
 * @param routerModulePath Path of the router module.
 * @param formName Form name.
 * @param path Path where the collection is being created (independently of
 * whether it is flat).
 * @param name Collection name.
 * @param schemaPath Path of the collection's schema.
 * @param formSchemaPath Path of the form's schema.
 * @param storagePathId Id of the collection in the storage path.
 * @param parentStoragePath Storage path of the collection's parent.
 * @param routeParams Param names for the collection's route.
 * @returns Schematic rule.
 */
export declare function createCollection(options: FormOptions, schemaExplorer: SchemaExplorer, moduleDir: Path, routerModulePath: Path | undefined, formName: string, path: Path, name: string, schemaPath: Path, formSchemaPath: Path, storagePathId: string, parentStoragePath: string, routeParams: string[]): Rule;
/**
 * Creates the form.
 * @param options Schematic options.
 * @param schemaExplorer `SchemaExplorer` instance.
 * @param moduleDir Module directory where to find the root schema.
 * @param routerModulePath Path of the router module.
 * @param path Path where the form is being created (independently of whether it
 * is flat).
 * @param name Form name.
 * @param schemaPath Path of the form's schema.
 * @param storagePathId Id of the form in the storage path.
 * @param parentStoragePath Storage path of the form's parent.
 * @param routeParams Param names for the form's route.
 * @returns Schematic rule.
 */
export declare function createForm(options: FormOptions, schemaExplorer: SchemaExplorer, moduleDir: Path, routerModulePath: Path | undefined, path: Path, name: string, schemaPath: Path, storagePathId: string, parentStoragePath: string, routeParams: string[]): Rule;
